@@ -4,7 +4,7 @@ use MooseX::Role::Parameterized;
 use Module::Runtime 'use_module';
 use List::AllUtils qw( first first_result );
 
-our $VERSION = '0.5.2';
+our $VERSION = '0.5.3';
 
 =head1 Model::Envoy
 
@@ -18,6 +18,7 @@ A Moose Role that can be used to build a model layer which keeps business logic
         with 'Model::Envoy' => { storage => {
             'DBIC' => {
                 schema => sub {
+                    my ( $class ) = @_;
                     My::DB->db_connect(...);
                 }
             },
@@ -104,6 +105,7 @@ do this in a base class which your models can inherit from:
         with 'Model::Envoy' => { storage => {
             'DBIC' => {
                 schema => sub {
+                    my ( $class ) = @_;
                     $schema ||= My::DB->db_connect(...);
                 }
             },
@@ -483,7 +485,7 @@ sub _get_configured_plugin_class {
 
     my $conf = $self->_plugins->{$store}{$package};
     if ( ! $conf->{_configured} ) {
-        $package->configure($conf);
+        $package->configure($self,$conf);
     }
 
     return $package;
